==> elgg-1.12.16.zip: elgg-1.12.16/mod/file/languages/nl.php <==
<?php
return array(

	/**
	 * Menu items and titles
	 */
	'file' => "Bestanden",
	'file:user' => "Bestanden van %s",
	'file:friends' => "Bestanden van vrienden",
	'file:all' => "Alle bestanden op de site",
	'file:edit' => "Bewerk bestand",
	'file:more' => "Meer bestanden",
	'file:list' => "lijstweergave",
	'file:group' => "Groepsbestanden",
	'file:gallery' => "galerijweergave",
	'file:gallery_list' => "Galerij- of lijstweergave",
	'file:num_files' => "Aantal bestanden om weer te geven",
	'file:user:gallery'=>'Bekijk de galerij van %s',
	'file:upload' => "Upload een bestand",
	'file:replace' => 'Vervang bestandsinhoud (laat dit leeg om het bestand <em>niet</em> te vervangen)',
	'file:list:title' => "Van %s: %s en %s",
	'file:title:friends' => "Vrienden",

	'file:add' => 'Upload een bestand',

	'file:file' => "Bestand",

	'file:list:list' => 'Toon in lijstweergave',
	'file:list:gallery' => 'Toon in galerijweergave',

	'file:types' => "Geplaatste bestandstypen",

	'file:type:' => 'Bestanden',
	'file:type:all' => "Alle bestanden",
	'file:type:video' => "Video's",
	'file:type:document' => "Documenten",
	'file:type:audio' => "Geluidsbestanden",
	'file:type:image' => "Afbeeldingen",
	'file:type:general' => "Algemeen",

	'file:user:type:video' => "Video's van %s",
	'file:user:type:document' => "Documenten van %s",
	'file:user:type:audio' => "Geluidsbestanden van %s",
	'file:user:type:image' => "Afbeeldingen van %s",
	'file:user:type:general' => "Algemene bestanden van %s",

	'file:friends:type:video' => "Video's van je vrienden",
	'file:friends:type:document' => "Documenten van je vrienden",
	'file:friends:type:audio' => "Geluidsbestanden van je vrienden",
	'file:friends:type:image' => "Afbeeldingen van je vrienden",
	'file:friends:type:general' => "Algemene bestanden van je vrienden",

	'file:widget' => "Bestandenwidget",
	'file:widget:description' => "Laat je laatst geüploade bestanden zien",

	'groups:enablefiles' => 'Activeer groepsbestanden',

	'file:delete:confirm' => "Weet je zeken dat je dit bestand wilt verwijderen?",

	'file:upload_limit' => 'Maximaal toegestane bestandsgrootte is %s',

	'file:tagcloud' => "Tag-cloud",

	'file:display:number' => "Aantal bestanden om weer te geven",

	'river:create:object:file' => '%s heeft het bestand %s geüpload',
	'river:comment:object:file' => '%s reageerde op het bestand %s',

	'item:object:file' => 'Bestanden',

	'file:notify:summary' => 'Nieuw bestand met de titel %s',
	'file:notify:subject' => 'Nieuw bestand: %s',
	'file:notify:body' =>
'Hallo!

%s heeft een nieuw bestand geüpload.

%s
%s

Je kunt het bestand hier bekijken:
%s

-----

Dit is een automatisch aangemaakt bericht. Je kunt hier niet op reageren.
',

	/**
	 * Status messages
	 */

	'file:saved' => "Je bestand is succesvol opgeslagen.",
	'file:deleted' => "Je bestand is succesvol verwijderd.",

	/**
	 * Error messages
	 */

	'file:none' => "We konden op dit moment geen bestanden vinden.",
	'file:uploadfailed' => "Sorry, we konden het bestand niet opslaan.",
	'file:downloadfailed' => "Sorry, dit bestand is op dit moment niet beschikbaar.",
	'file:deletefailed' => "Je bestand kon op dit moment niet worden verwijderd.",
	'file:noaccess' => "Je hebt onvoldoende rechten om dit bestand aan te passen",
	'file:cannotload' => "There was an error uploading the file",
	'file:nofile' => "Selecteer een bestand",
);

==> elgg-2.3.11.zip: elgg-2.3.11/mod/file/languages/nl.php <==
<?php
return array(

	/**
	 * Menu items and titles
	 */
	'file' => "Bestanden",
	'file:user' => "Bestanden van %s",
	'file:friends' => "Bestanden van vrienden",
	'file:all' => "Alle bestanden op de site",
	'file:edit' => "Bewerk bestand",
	'file:more' => "Meer bestanden",
	'file:list' => "lijstweergave",
	'file:group' => "Groepsbestanden",
	'file:gallery' => "galerijweergave",
	'file:gallery_list' => "Galerij- of lijstweergave",
	'file:num_files' => "Aantal bestanden om weer te geven",
	'file:user:gallery'=>'Bekijk de galerij van %s',
	'file:upload' => "Upload een bestand",
	'file:replace' => 'Vervang bestandsinhoud (laat dit leeg om het bestand <em>niet</em> te vervangen)',
	'file:list:title' => "Van %s: %s en %s",
	'file:title:friends' => "Vrienden",

	'file:add' => 'Upload een bestand',

	'file:file' => "Bestand",

	'file:list:list' => 'Toon in lijstweergave',
	'file:list:gallery' => 'Toon in galerijweergave',

	'file:types' => "Geplaatste bestandstypen",

	'file:type:' => 'Bestanden',
	'file:type:all' => "Alle bestanden",
	'file:type:video' => "Video's",
	'file:type:document' => "Documenten",
	'file:type:audio' => "Geluidsbestanden",
	'file:type:image' => "Afbeeldingen",
	'file:type:general' => "Algemeen",

	'file:user:type:video' => "Video's van %s",
	'file:user:type:document' => "Documenten van %s",
	'file:user:type:audio' => "Geluidsbestanden van %s",
	'file:user:type:image' => "Afbeeldingen van %s",
	'file:user:type:general' => "Algemene bestanden van %s",

	'file:friends:type:video' => "Video's van je vrienden",
	'file:friends:type:document' => "Documenten van je vrienden",
	'file:friends:type:audio' => "Geluidsbestanden van je vrienden",
	'file:friends:type:image' => "Afbeeldingen van je vrienden",
	'file:friends:type:general' => "Algemene bestanden van je vrienden",

	'file:widget' => "Bestandenwidget",
	'file:widget:description' => "Laat je laatst geüploade bestanden zien",

	'groups:enablefiles' => 'Activeer groepsbestanden',

	'file:delete:confirm' => "Weet je zeken dat je dit bestand wilt verwijderen?",

	'file:upload_limit' => 'Maximaal toegestane bestandsgrootte is %s',

	'file:tagcloud' => "Tag-cloud",

	'file:display:number' => "Aantal bestanden om weer te geven",

	'river:create:object:file' => '%s heeft het bestand %s geüpload',
	'river:comment:object:file' => '%s reageerde op het bestand %s',

	'item:object:file' => 'Bestanden',

	'file:notify:summary' => 'Nieuw bestand met de titel %s',
	'file:notify:subject' => 'Nieuw bestand: %s',
	'file:notify:body' =>
'Hallo!

%s heeft een nieuw bestand geüpload.

%s
%s

Je kunt het bestand hier bekijken:
%s

-----

Dit is een automatisch aangemaakt bericht. Je kunt hier niet op reageren.
',

	/**
	 * Status messages
	 */

	'file:saved' => "Je bestand is succesvol opgeslagen.",
	'file:deleted' => "Je bestand is succesvol verwijderd.",

	/**
	 * Error messages
	 */

	'file:none' => "We konden op dit moment geen bestanden vinden.",
	'file:uploadfailed' => "Sorry, we konden het bestand niet opslaan.",
	'file:downloadfailed' => "Sorry, dit bestand is op dit moment niet beschikbaar.",
	'file:deletefailed' => "Je bestand kon op dit moment niet worden verwijderd.",
	'file:noaccess' => "Je hebt onvoldoende rechten om dit bestand aan te passen",
	'file:cannotload' => "Er was een fout tijdens het uploaden van het bestand",
	'file:nofile' => "Selecteer een bestand",
);
